#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_IDIVCEIL_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_IDIVCEIL_HPP_INCLUDED

#include <boost/simd/arithmetic/include/functions/idivceil.hpp>

#endif
